###### Update Useful Libraries ####
library(tidyverse)
library(caret)
library(AER)


###################################################################
###################################################################
##############   banknote authentication Data Set  ################
###################################################################
###################################################################

#Source:
#Owner of database: Volker Lohweg 
#Date received: August, 2012 

#Data Set Information:
#Data were extracted from images that were taken from genuine and forged banknote-like
#specimens. For digitization, an industrial camera usually used for print inspection was used. 
#The final images have 400x 400 pixels. Due to the object lens and distance to the investigated
#object gray-scale pictures with a resolution of about 660 dpi were gained. Wavelet Transform tool
#were used to extract features from images.

#Attribute Information:
# 1. variance of Wavelet Transformed image (continuous) 
# 2. skewness of Wavelet Transformed image (continuous) 
# 3. curtosis of Wavelet Transformed image (continuous) 
# 4. entropy of image (continuous) 
# 5. class (integer) 


# 1)  Upload data

# data<-read.csv("data_banknote_authentication.txt", header = FALSE, sep=",")

# 2)  Quick exploratory data analysis

data<-read.csv("data_banknote_authentication.txt", header = FALSE, sep = ",")
colnames(data)<-c("variance", "skewness", "curtosis","entropy", "class" )

hist(data$variance,xlab = "x", ylab="Frequency", main="Variance", freq = TRUE)
hist(data$variance,xlab = "x", ylab="Density", main="Variance", freq = FALSE)

#scatter plot 
plot(data$variance, data$skewness, xlab = "Variance", ylab="Skewness")
plot(data$variance, data$class, xlab = "Variance", ylab="Skewness")

# 3) Choose a model basing on the data
mod1<-glm(class~., family = binomial(link="logit"), data=data)
summary(mod1)
coeftest(mod1, vcov. = vcovHC)
McFaddenR2<-1-mod1$deviance/mod1$null.deviance
#4) Intepretation of the estimates and Model Diagnostics

# 5) Prediction!
library(caret)
library(tidyverse)

#Alternatively, via "caret" library we can use the createDataPartition function
training.samples <- data$class %>% 
  createDataPartition(p = 0.8, list = FALSE)
train.data  <- data[training.samples, ]
test.data <- data[-training.samples, ]
# Fit the model
model <- glm( class ~., data = train.data, family = binomial)
# Summarize the model
summary(model)
# Make predictions
probabilities <- model %>% predict(test.data, type = "response")
predicted.classes <- ifelse(probabilities > 0.5, 1, 0)
# Model accuracy
mean(predicted.classes == test.data$class)




###################################################################
###################################################################
#########   default of credit card clients Data Set ###############
###################################################################
###################################################################

#Source:

#Name: I-Cheng Yeh 
#institutions: Department of Information Management, Chung Hua University, Taiwan. (2) Department of Civil Engineering, Tamkang University, Taiwan. 


#Data Set Information:

#This research aimed at the case of customers default payments in Taiwan and compares the 
#predictive accuracy of probability of default among six data mining methods. From the 
#perspective of risk management, the result of predictive accuracy of the estimated 
#probability of default will be more valuable than the binary result of classification - 
#credible or not credible clients. Because the real probability of default is unknown, 
#this study presented the novel â€œSorting Smoothing Methodâ€ to estimate the real 
#probability of default. With the real probability of default as the response variable (Y),
#and the predictive probability of default as the independent variable (X), the simple 
#linear regression result (Y = A + BX) shows that the forecasting model produced by 
#artificial neural network has the highest coefficient of determination; its regression 
#intercept (A) is close to zero, and regression coefficient (B) to one. Therefore, among 
#the six data mining techniques, artificial neural network is the only one that can 
#accurately estimate the real probability of default.


#Attribute Information:

#This research employed a binary variable, default payment (Yes = 1, No = 0), as the 
#response variable. This study reviewed the literature and used the following 23 variables
#as explanatory variables: 
#X1: Amount of the given credit (NT dollar): it includes both the individual consumer credit 
#and his/her family (supplementary) credit. 
#X2: Gender (1 = male; 2 = female). 
#X3: Education (1 = graduate school; 2 = university; 3 = high school; 4 = others). 
#X4: Marital status (1 = married; 2 = single; 3 = others). 
#X5: Age (year). 
#X6 - X11: History of past payment. We tracked the past monthly payment records (from April 
#to September, 2005) as follows: X6 = the repayment status in September, 2005; X7 = the 
#repayment status in August, 2005; . . .;X11 = the repayment status in April, 2005. 
#The measurement scale for the repayment status is: -1 = pay duly; 1 = payment delay for 
#one month; 2 = payment delay for two months; . . .; 8 = payment delay for eight months; 
#9 = payment delay for nine months and above. 
#X12-X17: Amount of bill statement (NT dollar). X12 = amount of bill statement in September, 
#2005; X13 = amount of bill statement in August, 2005; . . .; X17 = amount of bill statement 
#in April, 2005. 
#X18-X23: Amount of previous payment (NT dollar). X18 = amount paid in September, 2005; 
#X19 = amount paid in August, 2005; . . .;X23 = amount paid in April, 2005. 


library(creditmodel)
data("UCICreditCard")
head(UCICreditCard)
dim(UCICreditCard)
UCICreditCard<-na.omit(UCICreditCard)
dim(UCICreditCard)

# 1) Quick exploratory data analysis

# 2) Choose a model basing on the data

# 3) Intepretation of the estimates and Model Diagnostics

# 4) Prediction!




###################################################################
###################################################################
#################   Fishing at Park data     ######################
###################################################################
###################################################################



zinb <- read.csv("https://stats.idre.ucla.edu/stat/data/fish.csv")
zinb <- within(zinb, {
  nofish <- factor(nofish)
  livebait <- factor(livebait)
  camper <- factor(camper)
})


# We have data on 250 groups that went to a park. 
# Each group was questioned about how many fish they caught (count)
# how many children were in the group (child)
# how many people were in the group (persons)
# whether or not they brought a camper to the park (camper).


###################################################################
###################################################################
###### Number of publications produced by Ph.D. biochemists #######
###################################################################
###################################################################



library(foreign)
data <- read.dta("http://www.stata-press.com/data/lf2/couart2.dta")
names(data)

#art	articles in last three years of Ph.D.
#fem	coded one for females
#mar	coded one if married
#kid5	number of children under age six
#phd	prestige of Ph.D. program
#ment	articles by mentor in last three years






